@@ -77,11 +77,13 @@ from beartype.roar._roarexc import (
 from beartype.typing import (
     Callable,
     Dict,
-    NoReturn,
+    # NoReturn,
     Optional,
 )
-from beartype._cave._cavemap import NoneTypeOr
+# from beartype._cave._cavemap import NoneTypeOr
 from beartype._conf.confcls import BeartypeConf
+from beartype._data.datakind import ARG_NAME_RETURN
+from beartype._data.datatyping import TypeStack
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignAnnotated,
@@ -104,11 +106,14 @@ from beartype._decor._error._util.errorutilcolor import (
     strip_text_ansi_if_configured,
 )
 from beartype._decor._error._util.errorutiltext import (
-    prefix_callable_decorated_arg_value,
-    prefix_callable_decorated_return_value,
+    prefix_beartypeable_arg_value,
+    prefix_beartypeable_return_value,
+)
+# from beartype._util.hint.utilhinttest import die_unless_hint
+from beartype._util.text.utiltextmunge import (
+    suffix_unless_suffixed,
+    uppercase_char_first,
 )
-from beartype._util.hint.utilhinttest import die_unless_hint
-from beartype._util.text.utiltextmunge import suffix_unless_suffixed
 from beartype._util.text.utiltextrepr import represent_object
 from beartype._data.datatyping import TypeException
 
@@ -119,7 +124,7 @@ PEP_HINT_SIGN_TO_GET_CAUSE_FUNC: Dict[
 '''
 Dictionary mapping each **sign** (i.e., arbitrary object uniquely identifying a
 PEP-compliant type) to a private getter function defined by this submodule
-whose signature matches that of the :func:`_find_cause` function and
+whose signature matches that of the :func:`._find_cause` function and
 which is dynamically dispatched by that function to describe type-checking
 failures specific to that unsubscripted :mod:`typing` attribute.
 '''
@@ -133,6 +138,7 @@ def get_beartype_violation(
     pith_value: object,
 
     # Optional parameters.
+    cls_stack: TypeStack = None,
     random_int: Optional[int] = None,
 ) -> BeartypeCallHintViolation:
     '''
@@ -193,14 +199,19 @@ def get_beartype_violation(
           value returned from this callable.
     pith_value : object
         Passed parameter or returned value violating this hint.
-    random_int: Optional[int]
+    cls_stack : TypeStack, optional
+        **Type stack** (i.e., either a tuple of the one or more
+        :func:`beartype.beartype`-decorated classes lexically containing the
+        class variable or method annotated by this hint *or* :data:`None`).
+        Defaults to :data:`None`.
+    random_int: Optional[int], optional
         **Pseudo-random integer** (i.e., unsigned 32-bit integer
         pseudo-randomly generated by the parent :func:`beartype.beartype`
         wrapper function in type-checking randomly indexed container items by
         the current call to that function) if that function generated such an
-        integer *or* ``None`` otherwise (i.e., if that function generated *no*
-        such integer). Note that this parameter critically governs whether this
-        exception handler runs in constant or linear time. Specifically, if
+        integer *or* :data:`None` otherwise (i.e., if that function generated
+        *no* such integer). Note that this parameter critically governs whether
+        this exception handler runs in constant or linear time. Specifically, if
         this parameter is:
 
         * An integer, this handler runs in **constant time.** Since there
@@ -210,9 +221,9 @@ def get_beartype_violation(
           enables this handler to efficiently re-type-check the same random
           container item(s) type-checked by the parent in constant time rather
           type-checking all container items in linear time.
-        * ``None``, this handler runs in **linear time.**
+        * :data:`None`, this handler runs in **linear time.**
 
-        Defaults to ``None``, implying this exception handler runs in linear
+        Defaults to :data:`None`, implying this exception handler runs in linear
         time by default.
 
     Returns
@@ -222,9 +233,9 @@ def get_beartype_violation(
         return to satisfy the PEP-compliant type hint annotating this parameter
         or return value, guaranteed to be an instance of either:
 
-        * :class:`BeartypeCallHintParamViolation`, if the object failing to
+        * :class:`.BeartypeCallHintParamViolation`, if the object failing to
           satisfy this hint is a parameter.
-        * :class:`BeartypeCallHintReturnViolation`, if the object failing to
+        * :class:`.BeartypeCallHintReturnViolation`, if the object failing to
           satisfy this hint is a return.
 
     Raises
@@ -246,8 +257,6 @@ def get_beartype_violation(
     assert callable(func), f'{repr(func)} uncallable.'
     assert isinstance(conf, BeartypeConf), f'{repr(conf)} not configuration.'
     assert isinstance(pith_name, str), f'{repr(pith_name)} not string.'
-    assert isinstance(random_int, NoneTypeOr[int]), (
-        f'{repr(random_int)} neither integer nor "None".')
 
     # print('''get_beartype_violation(
     #     func={!r},
@@ -260,22 +269,26 @@ def get_beartype_violation(
     # Type of exception to be raised.
     exception_cls: TypeException = None  # type: ignore[assignment]
 
-    # Human-readable label describing this parameter or return value.
+    # Substring prefixing the message of the violation to be raised below,
+    # initialized to a human-readable label describing this parameter or return.
     exception_prefix: str = None  # type: ignore[assignment]
 
     # If the name of this parameter is the magic string implying the passed
     # object to be a return value, set the above local variables appropriately.
-    if pith_name == 'return':
+    if pith_name == ARG_NAME_RETURN:
         exception_cls = BeartypeCallHintReturnViolation
-        exception_prefix = prefix_callable_decorated_return_value(
+        exception_prefix = prefix_beartypeable_return_value(
             func=func, return_value=pith_value)
     # Else, the passed object is a parameter. In this case, set the above local
     # variables appropriately.
     else:
         exception_cls = BeartypeCallHintParamViolation
-        exception_prefix = prefix_callable_decorated_arg_value(
+        exception_prefix = prefix_beartypeable_arg_value(
             func=func, arg_name=pith_name, arg_value=pith_value)
 
+    # Uppercase the first character of this violation message prefix if needed.
+    exception_prefix = uppercase_char_first(exception_prefix)
+
     # ....................{ HINTS                          }....................
     # If this parameter or return value is unannotated, raise an exception.
     #
@@ -295,12 +308,13 @@ def get_beartype_violation(
     # Cause describing the failure of this pith to satisfy this hint.
     violation_cause = ViolationCause(
         func=func,
+        cause_indent='',
+        cls_stack=cls_stack,
         conf=conf,
+        exception_prefix=exception_prefix,
+        hint=hint,
         pith=pith_value,
         pith_name=pith_name,
-        hint=hint,
-        cause_indent='',
-        exception_prefix=exception_prefix,
         random_int=random_int,
     ).find_cause()
 
