@@ -33,6 +33,7 @@ from beartype._cave._cavefast import (
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
+from beartype._cave._cavemap import NoneTypeOr
 from beartype._conf.confcls import BeartypeConf
 from beartype._conf.confenum import BeartypeStrategy
 from beartype._data.datatyping import (
@@ -53,8 +54,10 @@ from beartype._util.func.lib.utilbeartypefunc import (
 )
 from beartype._util.func.utilfuncmake import make_func
 from beartype._util.func.utilfunctest import is_func_python
-from beartype._util.mod.utilmodget import get_object_module_line_number_begin
-from beartype._util.utilobject import get_object_name
+from beartype._util.text.utiltextansi import strip_text_ansi
+from beartype._util.text.utiltextlabel import label_object_context
+from beartype._util.text.utiltextmunge import uppercase_char_first
+from beartype._util.text.utiltextprefix import prefix_beartypeable
 from traceback import format_exc
 from warnings import warn
 
@@ -77,76 +80,14 @@ def beartype_object(
     obj : BeartypeableT
         **Beartypeable** (i.e., pure-Python callable or class) to be decorated.
     conf : BeartypeConf
-        **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all flags, options, settings, and other metadata configuring the
-        current decoration of the decorated callable or class).
-    cls_stack : TypeStack
-        Either:
-
-        * If this beartypeable is an attribute (e.g., method, nested class) of a
-          class currently being decorated by the :func:`beartype.beartype`
-          decorator, the **type stack** (i.e., tuple of one or more lexically
-          nested classes that are either currently being decorated *or* have
-          already been decorated by this decorator in descending order of
-          top- to bottom-most lexically nested) such that:
-
-          * The first item of this tuple is expected to be the **root decorated
-            class** (i.e., module-scoped class initially decorated by this
-            decorator whose lexical scope encloses this beartypeable).
-          * The last item of this tuple is expected to be the **current
-            decorated class** (i.e., possibly nested class currently being
-            decorated by this decorator).
-
-        * Else, this beartypeable was decorated directly by this decorator. In
-          this case, ``None``.
-
-        Defaults to ``None``.
-
-        Note that this decorator requires *both* the root and currently
-        decorated class to correctly resolve edge cases under :pep:`563`: e.g.,
-
-        .. code-block:: python
-
-           from __future__ import annotations
-           from beartype import beartype
-
-           @beartype
-           class Outer(object):
-               class Inner(object):
-                   # At this time, the "Outer" class has been fully defined but
-                   # is *NOT* yet accessible as a module-scoped attribute. Ergo,
-                   # the *ONLY* means of exposing the "Outer" class to the
-                   # recursive decoration of this get_outer() method is to
-                   # explicitly pass the "Outer" class as the "cls_root"
-                   # parameter to all decoration calls.
-                   def get_outer(self) -> Outer:
-                       return Outer()
-
-        Note also that nested classes have *no* implicit access to either their
-        parent classes *or* to class variables declared by those parent classes.
-        Nested classes *only* have explicit access to module-scoped classes --
-        exactly like any other arbitrary objects: e.g.,
-
-        .. code-block:: python
-
-           class Outer(object):
-               my_str = str
-
-               class Inner(object):
-                   # This induces a fatal compile-time exception resembling:
-                   #     NameError: name 'my_str' is not defined
-                   def get_str(self) -> my_str:
-                       return 'Oh, Gods.'
-
-        Ergo, the *only* owning class of interest to :mod:`beartype` is the root
-        owning class containing other nested classes; *all* of those other
-        nested classes are semantically and syntactically irrelevant.
-        Nonetheless, this tuple intentionally preserves *all* of those other
-        nested classes. Why? Because :pep:`563` resolution can only find the
-        parent callable lexically containing that nested class hierarchy on the
-        current call stack (if any) by leveraging the total number of classes
-        lexically nesting the currently decorated class as input metadata, as
-        trivially provided by the length of this tuple.
+        **Beartype configuration** (i.e., dataclass encapsulating all flags,
+        options, settings, and other metadata configuring the current decoration
+        of the decorated callable or class).
+    cls_stack : TypeStack, optional
+        **Type stack** (i.e., either a tuple of the one or more
+        :func:`beartype.beartype`-decorated classes lexically containing the
+        class variable or method annotated by this hint *or* :data:`None`).
+        Defaults to :data:`None`.
 
     Returns
     ----------
@@ -260,12 +201,14 @@ def beartype_object(
     )
 
 
-#FIXME: Generalize to accept a "cls_stack" parameter, please.
 #FIXME: Unit test us up, please.
 def beartype_object_nonfatal(
+    # Mandatory parameters.
     obj: BeartypeableT,
-    conf: BeartypeConf,
     warning_category: TypeWarning,
+
+    # Optional parameters.
+    **kwargs
 ) -> BeartypeableT:
     '''
     Decorate the passed **beartypeable** (i.e., pure-Python callable or class)
@@ -293,46 +236,44 @@ def beartype_object_nonfatal(
 
       * Emit a warning for each callable or class that :func:`beartype.beartype`
         fails to generate a type-checking wrapper for.
-      * Proceed to the next callable or class.
+      * Continue to the next callable or class.
 
     Parameters
     ----------
     obj : BeartypeableT
         **Beartypeable** (i.e., pure-Python callable or class) to be decorated.
-    conf : BeartypeConf, optional
-        **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all flags, options, settings, and other metadata configuring the
-        current decoration of the decorated callable or class).
     warning_category : TypeWarning
         Category of the non-fatal warning to emit if :func:`beartype.beartype`
         fails to generate a type-checking wrapper for this callable or class.
 
+    All remaining keyword parameters are passed as is to the lower-level
+    :func:`.beartype_object` decorator internally called by this higher-level
+    decorator on the passed beartypeable.
+
     Returns
     ----------
     BeartypeableT
         Either:
 
-        * If the passed object is a class, this existing class embellished with
-          dynamically generated type-checking.
-        * If the passed object is a callable, a new callable wrapping that
-          callable with dynamically generated type-checking.
+        * If :func:`.beartype_object` raises an exception, the passed object
+          unmodified as is.
+        * If :func:`.beartype_object` raises no exception:
+          * If the passed object is a class, this existing class embellished with
+            dynamically generated type-checking.
+          * If the passed object is a callable, a new callable wrapping that
+            callable with dynamically generated type-checking.
 
     Warns
     ----------
     warning_category
-        If :func:`beartype.beartype` fails to generate a type-checking wrapper
+        If :func:`.beartype_object` fails to generate a type-checking wrapper
         for this callable or class by raising a fatal exception, this function
         coerces that exception into a non-fatal warning describing that error.
-
-    See Also
-    ----------
-    :func:`beartype._decor.decormain.beartype`
-        Memoized parent decorator wrapping this unmemoized child decorator.
     '''
 
     # Attempt to decorate the passed beartypeable.
     try:
-        return beartype_object(obj, conf)
+        return beartype_object(obj, **kwargs)
     # If doing so unexpectedly raises an exception, coerce that fatal exception
     # into a non-fatal warning for nebulous safety.
     except Exception as exception:
@@ -340,8 +281,13 @@ def beartype_object_nonfatal(
             f'{repr(warning_category)} not warning category.')
 
         # Original error message to be embedded in the warning message to be
-        # emitted, defined as either...
-        error_message = (
+        # emitted, stripped of *ALL* ANSI color. While colors improve the
+        # readability of exception messages that percolate down to an ANSI-aware
+        # command line, warnings are usually harvested and then regurgitated by
+        # intermediary packages into ANSI-unaware logfiles.
+        #
+        # This message is defined as either...
+        error_message = strip_text_ansi(
             # If this exception is beartype-specific, this exception's message
             # is probably human-readable as is. In this case, coerce only that
             # message directly into a warning for brevity and readability.
@@ -350,39 +296,25 @@ def beartype_object_nonfatal(
             # Else, this exception is *NOT* beartype-specific. In this case,
             # this exception's message is probably *NOT* human-readable as is.
             # Prepend that non-human-readable message by this exception's
-            # traceback to for disambiguity and debuggability. Note that the
+            # traceback for disambiguity and debuggability. Note that the
             # format_exc() function appends this exception's message to this
             # traceback and thus suffices as is.
             format_exc()
         )
 
-        #FIXME: Unconditionally parse this warning message by globally replacing
-        #*EACH* newline (i.e., "\n" substring) in this message with a newline
-        #followed by four spaces (i.e., "\n    ").
+        # Indent this exception message by globally replacing *EVERY* newline in
+        # this message with a newline followed by four spaces. Doing so visually
+        # offsets this lower-level exception message from the higher-level
+        # warning message embedding this exception message below.
+        error_message = error_message.replace('\n', '\n    ')
 
-        #FIXME: Inadequate, really. Instead defer to the:
-        #* "label_callable(func=obj, is_contextualized=True)" function if this
-        #  object is *NOT* a class.
-        #* "label_class(cls=obj, is_contextualized=True)" function if this
-        #  object is a class. Of course, that function currently accepts no such
-        #  "is_contextualized" parameter. Make it so, please. *sigh*
-        #
-        #This suggests we probably just want to define a new higher-level
-        #label_object() function with signature resembling:
-        #    label_object(obj: object, is_contextualized: Optional[bool] = None)
-        #FIXME: Note that we'll want to capitalize the first character of the
-        #string returned by the label_object() function, please.
-
-        # Fully-qualified name of this beartypeable.
-        obj_name = get_object_name(obj)
-
-        # Line number of the first line declaring this beartypeable in its
-        # underlying source code module file.
-        obj_lineno = get_object_module_line_number_begin(obj)
-
-        # Warning message to be emitted.
-        warning_message = (
-            error_message
+        # Warning message to be emitted, consisting of:
+        # * A human-readable label contextually describing this beartypeable,
+        #   capitalized such that the first character is uppercase.
+        # * This indented exception message.
+        warning_message = uppercase_char_first(
+            f'{prefix_beartypeable(obj)}{label_object_context(obj)}:\n'
+            f'{error_message}'
         )
 
         # Emit this message under this category.
@@ -390,7 +322,7 @@ def beartype_object_nonfatal(
 
     # Return this object unmodified, as @beartype failed to successfully wrap
     # this object with a type-checking class or callable. So it goes, fam.
-    return obj
+    return obj  # type: ignore[return-value]
 
 # ....................{ PRIVATE ~ beartypers : func        }....................
 def _beartype_decorator_builtin(
@@ -742,10 +674,11 @@ def _beartype_type(
     conf : BeartypeConf
         Beartype configuration configuring :func:`beartype.beartype` uniquely
         specific to this class.
-    cls_stack : TypeStack
-        **Type stack** (i.e., either tuple of zero or more arbitrary types *or*
-        ``None``). Defaults to ``None``. See also the :func:`beartype_object`
-        decorator for further commentary.
+    cls_stack : TypeStack, optional
+        **Type stack** (i.e., either a tuple of the one or more
+        :func:`beartype.beartype`-decorated classes lexically containing the
+        class variable or method annotated by this hint *or* :data:`None`).
+        Defaults to :data:`None`.
 
     Returns
     ----------
@@ -753,9 +686,9 @@ def _beartype_type(
         This class decorated by :func:`beartype.beartype`.
     '''
     assert isinstance(cls, type), f'{repr(cls)} not type.'
+    assert isinstance(cls_stack, NoneTypeOr[tuple]), (
+        f'{repr(cls_stack)} neither tuple nor "None".')
     # assert isinstance(conf, BeartypeConf), f'{repr(conf)} not configuration.'
-    # assert isinstance(cls_root, NoneTypeOr[type]), (
-    #     f'{repr(cls_root)} neither type nor "None".')
 
     #FIXME: Insufficient. We also want to set a beartype-specific dunder
     #attribute -- say, "__beartyped" -- on this class. Additionally, if this
@@ -875,7 +808,7 @@ def _monkeypatch_object(
         specific to this descriptor.
 
     All remaining keyword parameters are passed as is to the lower-level
-    :func:`_beartype_func` decorator internally called by this higher-level
+    :func:`._beartype_func` decorator internally called by this higher-level
     decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
