@@ -28,7 +28,7 @@ from types import CodeType
 # ....................{ TESTERS                            }....................
 def is_func_nested(func: Callable) -> bool:
     '''
-    ``True`` only if the passed callable is **nested** (i.e., a pure-Python
+    :data:`True` only if the passed callable is **nested** (i.e., a pure-Python
     callable declared in the body of another pure-Python callable).
 
     Parameters
@@ -39,7 +39,7 @@ def is_func_nested(func: Callable) -> bool:
     Returns
     ----------
     bool
-        ``True`` only if this callable is nested.
+        :data:`True` only if this callable is nested.
     '''
     assert callable(func), f'{repr(func)} not callable.'
 
@@ -617,7 +617,7 @@ def add_func_scope_attr(
 
     Raises
     ----------
-    :exc:`_BeartypeUtilCallableException`
+    :exc:`._BeartypeUtilCallableException`
         If an attribute with the same name as that internally generated by
         this adder but having a different value already exists in this scope.
         This adder uniquifies names by object identifier and should thus
@@ -628,9 +628,37 @@ def add_func_scope_attr(
     assert isinstance(exception_prefix, str), (
         f'{repr(exception_prefix)} not string.')
 
-    # Name of the new attribute referring to this object in this scope, mildly
-    # obfuscated so as to avoid name collisions.
-    attr_name = f'__beartype_object_{id(attr)}'
+    # Possibly negative integer uniquely identifying the new attribute referring
+    # to this object in this scope.
+    attr_id = id(attr)
+
+    # Name of the new attribute referring to this object in this scope, defined
+    # as either...
+    attr_name = (
+        # If this integer is positive, embed this positive integer into this
+        # name as is.
+        f'{_ATTR_NAME_PREFIX_ID_POSITIVE}{attr_id}'
+        if attr_id >= 0 else
+        # Else, this integer is negative. In this case, instead embed the
+        # absolute value of this negative integer rather than this negative
+        # integer itself. The unary prefix "-" is prohibited in Python
+        # identifiers. Since this integer is subsequently embedded in a Python
+        # identifier, this integer *MUST* be coerced from a negative to
+        # non-negative integer first.
+        #
+        # Note that this edge case *ONLY* applies to PyPy. Specifically, under:
+        # * CPython, this integer is guaranteed to be a memory address and thus
+        #   non-negative (i.e., "id(attr) >= 0" for all possible attributes).
+        # * PyPy, this integer is typically (but *NOT* necessarily) a 0-based
+        #   index into an internal object array and thus also non-negative.
+        #   Unfortunately, this heuristic is *NOT* a universal guarantee. In a
+        #   small handful of edge cases (for presumably exotic objects of
+        #   unknown origin), this integer is negative under PyPy. This makes
+        #   testing non-deterministic and thus infeasible.
+        #
+        # This must be what it feels like when code cries.
+        f'{_ATTR_NAME_PREFIX_ID_NEGATIVE}{-attr_id}'  # pragma: no cover
+    )
 
     # If an attribute with the same name but differing value already exists in
     # this scope, raise an exception.
@@ -648,3 +676,34 @@ def add_func_scope_attr(
 
     # Return this name.
     return attr_name
+
+# ....................{ PRIVATE                            }....................
+_ATTR_NAME_PREFIX_ID_POSITIVE = '__beartype_object_'
+'''
+Arbitrary substring prefixing names dynamically synthesized by the
+:func:`.add_func_scope_attr` function for attributes whose **object ids** (i.e.,
+the integers returned by the :func:`id` builtin) are positive.
+
+See Also
+----------
+:data:`._ATTR_NAME_PREFIX_ID_NEGATIVE`
+    Further details.
+'''
+
+
+# NegaBeartype: I challenge you!
+_ATTR_NAME_PREFIX_ID_NEGATIVE = (
+    f'{_ATTR_NAME_PREFIX_ID_POSITIVE}oh_pypy_you_sweet_summer_child_')
+'''
+Arbitrary substring prefixing names dynamically synthesized by the
+:func:`.add_func_scope_attr` function for attributes whose **object ids** (i.e.,
+the integers returned by the :func:`id` builtin) are negative.
+
+Negative attribute ids are coerced into positive attribute ids. Doing so renders
+the former suitable for embedding in attribute names that are valid Python
+identifiers. That's good. Doing so naively, however, would invite name
+collisions between negative and positive attribute ids whose absolute values are
+equal (e.g., "|-42| == |42|"). To avoid this, the names of attributes whose ids
+are negative are prefixed by a different substring than those of attributes
+whose ids are positive. It's complicated. Did our hand-waving not convince you!?
+'''
