@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -16,6 +16,18 @@ from platform import system as platform_system
 from sys import platform as sys_platform
 
 # ....................{ TESTERS                            }....................
+@callable_cached
+def is_os_linux() -> bool:
+    '''
+    ``True`` only if the current platform is a **Linux distribution.**
+
+    This tester is memoized for efficiency.
+    '''
+
+    return platform_system() == 'Linux'
+
+
+
 @callable_cached
 def is_os_macos() -> bool:
     '''
