@@ -107,7 +107,9 @@ from beartype.roar._roarwarn import (
     BeartypeDecorHintPep585DeprecationWarning as BeartypeDecorHintPep585DeprecationWarning,
     BeartypeDecorHintNonpepWarning as BeartypeDecorHintNonpepWarning,
     BeartypeDecorHintNonpepNumpyWarning as BeartypeDecorHintNonpepNumpyWarning,
+    BeartypeModuleWarning as BeartypeModuleWarning,
     BeartypeModuleNotFoundWarning as BeartypeModuleNotFoundWarning,
+    BeartypeModuleAttributeNotFoundWarning as BeartypeModuleAttributeNotFoundWarning,
     BeartypeModuleUnimportableWarning as BeartypeModuleUnimportableWarning,
     BeartypeValeWarning as BeartypeValeWarning,
     BeartypeValeLambdaWarning as BeartypeValeLambdaWarning,
