@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
-# --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# --------------------( LICENSE                            )--------------------
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -10,14 +10,14 @@ This submodule unit tests the public API of the private
 :mod:`beartype._util.hint.pep.utilpepget` submodule.
 '''
 
-# ....................{ IMPORTS                           }....................
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+# ....................{ IMPORTS                            }....................
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # WARNING: To raise human-readable test errors, avoid importing from
 # package-specific submodules at module scope.
-#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # from beartype_test._util.mark.pytskip import skip_if_python_version_less_than
 
-# ....................{ TESTS ~ attr                      }....................
+# ....................{ TESTS ~ attr                       }....................
 def test_get_hint_pep_args() -> None:
     '''
     Test the
@@ -25,11 +25,18 @@ def test_get_hint_pep_args() -> None:
     getter.
     '''
 
-    # Defer heavyweight imports.
-    from beartype._util.hint.pep.utilpepget import get_hint_pep_args
+    # ....................{ IMPORTS                        }....................
+    # Defer test-specific imports.
+    from beartype._util.hint.pep.utilpepget import (
+        _HINT_ARGS_EMPTY_TUPLE,
+        get_hint_pep_args,
+    )
+    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
     from beartype_test.a00_unit.data.hint.data_hint import NOT_HINTS_PEP
     from beartype_test.a00_unit.data.hint.pep.data_pep import HINTS_PEP_META
+    from typing import Tuple
 
+    # ....................{ PASS                           }....................
     # For each PEP-compliant hint, assert this getter returns...
     for hint_pep_meta in HINTS_PEP_META:
         # Tuple of all arguments subscripting this hint.
@@ -43,6 +50,22 @@ def test_get_hint_pep_args() -> None:
         else:
             assert hint_args == ()
 
+    # ....................{ PASS ~ pep                     }....................
+    #FIXME: Explicitly validate that this getter handles both PEP 484- and 585-
+    #compliant empty tuples by returning "_HINT_ARGS_EMPTY_TUPLE" as expected,
+    #please. This is sufficiently critical that we *NEED* to ensure this.
+
+    # Assert that this getter when passed a PEP 484-compliant empty tuple type
+    # hint returns a tuple containing an empty tuple for disambiguity.
+    assert get_hint_pep_args(Tuple[()]) == _HINT_ARGS_EMPTY_TUPLE
+
+    # If Python >= 3.9, the active Python interpreter supports PEP 585. In this
+    # case, assert that this getter when passed a PEP 585-compliant empty tuple
+    # type hint returns a tuple containing an empty tuple for disambiguity.
+    if IS_PYTHON_AT_LEAST_3_9:
+        assert get_hint_pep_args(tuple[()]) == _HINT_ARGS_EMPTY_TUPLE
+
+    # ....................{ FAIL                           }....................
     # Assert this getter returns *NO* type variables for non-"typing" hints.
     for not_hint_pep in NOT_HINTS_PEP:
         assert get_hint_pep_args(not_hint_pep) == ()
@@ -55,7 +78,7 @@ def test_get_hint_pep_typevars() -> None:
     getter.
     '''
 
-    # Defer heavyweight imports.
+    # Defer test-specific imports.
     from beartype._data.hint.pep.sign.datapepsigns import HintSignTypeVar
     from beartype._util.hint.pep.utilpepget import (
         get_hint_pep_typevars,
@@ -84,14 +107,14 @@ def test_get_hint_pep_typevars() -> None:
     for not_hint_pep in NOT_HINTS_PEP:
         assert get_hint_pep_typevars(not_hint_pep) == ()
 
-# ....................{ TESTS ~ sign                      }....................
+# ....................{ TESTS ~ sign                       }....................
 def test_get_hint_pep_sign() -> None:
     '''
     Test the
     :func:`beartype._util.hint.pep.utilpepget.get_hint_pep_sign` getter.
     '''
 
-    # Defer heavyweight imports.
+    # Defer test-specific imports.
     from beartype.roar import BeartypeDecorHintPepSignException
     from beartype._util.hint.pep.utilpepget import get_hint_pep_sign
     from beartype_test.a00_unit.data.hint.data_hint import (
@@ -117,7 +140,7 @@ def test_get_hint_pep_sign() -> None:
             # Localize this return value to simplify debugging.
             hint_nonpep_sign = get_hint_pep_sign(hint_nonpep)
 
-# ....................{ TESTS ~ origin : type             }....................
+# ....................{ TESTS ~ origin : type              }....................
 def test_get_hint_pep_type_isinstanceable() -> None:
     '''
     Test the
@@ -125,7 +148,7 @@ def test_get_hint_pep_type_isinstanceable() -> None:
     getter.
     '''
 
-    # Defer heavyweight imports.
+    # Defer test-specific imports.
     from beartype.roar import BeartypeDecorHintPepException
     from beartype._util.hint.pep.utilpepget import (
         get_hint_pep_origin_type_isinstanceable)
@@ -160,7 +183,7 @@ def test_get_hint_pep_type_isinstanceable_or_none() -> None:
     getter.
     '''
 
-    # Defer heavyweight imports.
+    # Defer test-specific imports.
     from beartype.roar import BeartypeDecorHintPepException
     from beartype._util.hint.pep.utilpepget import (
         get_hint_pep_origin_type_isinstanceable_or_none)
